from django import forms
from django.contrib.auth.forms import UserChangeForm, UserCreationForm
from django.contrib.auth.models import User
from django.core.exceptions import ValidationError
from django.utils.translation import gettext_lazy as _

from .models import AuthConfiguration, Instrument, Profile


class ProfileForm(forms.ModelForm):
    class Meta:  # pyright: ignore
        model = Profile
        # abstract = True
        exclude = ["user"]
        widgets = {
            "instruments": forms.CheckboxSelectMultiple(),
        }


class ProfileCreateForm(ProfileForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["instruments"].choices = (
            (x.pk, x) for x in Instrument.objects.filter(is_main=True)
        )


class UserForm(UserChangeForm):
    password = None

    class Meta:  # pyright: ignore
        model = User
        fields = ["username", "email", "first_name", "last_name"]


class UserCreateForm(UserCreationForm):
    class Meta:  # pyright: ignore
        model = User
        fields = ["username", "email", "first_name", "last_name"]


class BecomeErnestoForm(forms.Form):
    password = forms.CharField(
        label=_("L'ernesto mot de passe"), widget=forms.PasswordInput
    )

    def clean_password(self):
        data = self.cleaned_data["password"]
        if data != AuthConfiguration.get_solo().password:
            raise ValidationError(_("Ernesto mot de passe incorrect"))
        return data
