# Create your models here.
from django.contrib.auth.models import User
from django.db import models
from django.utils.translation import gettext_lazy as _
from solo.models import SingletonModel


class AuthConfiguration(SingletonModel):
    password = models.CharField(
        max_length=255,
        default="dummy",
        verbose_name=_("Mot de passe pour devenir fanfaron"),
    )

    def __str__(self):
        return "Auth Configuration"

    class Meta:  # pyright: ignore
        verbose_name = _("Paramètres d'authentification")


class Instrument(models.Model):
    name = models.CharField(
        _("Nom de l'instrument"),
        max_length=50,
        blank=False,
        null=False,
        unique=True,
    )

    is_main = models.BooleanField(
        _("Instrument important"),
        default=False,
        help_text=_("Instrument qui sera montré lors de l'inscription sur le site"),
    )

    def __str__(self):
        return self.name


class Profile(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, related_name="profile")

    phone = models.CharField(
        _("Numéro de téléphone"),
        max_length=20,
        blank=True,
        default="",
        help_text=_("seulement visible par les chef·fe·s"),
    )

    polls_pseudo = models.CharField(
        _("Pseudo pour les sondages"),
        max_length=30,
        help_text=_("Le pseudo qui s'affichera pour tes réponses aux sondages"),
        unique=True,
        blank=False,
        null=False,
    )

    instruments = models.ManyToManyField(
        Instrument,
        blank=True,
        verbose_name=_("Instruments joués"),
        help_text=_("Appuyez sur ctrl pour en sélectionner plusieurs"),
    )

    class Meta:  # pyright: ignore
        verbose_name = _("Ernestoprofil")
        verbose_name_plural = _("Ernestoprofils")

    def __str__(self):
        return self.user.username
