from django.contrib import messages
from django.contrib.auth.mixins import AccessMixin
from django.http import HttpResponseRedirect


class LocalUserOnlyMixin(AccessMixin):
    """
    Verify that the current user is authenticated and a local user (not SSO
    user).
    """

    def dispatch(self, request, *args, **kwargs):
        if hasattr(request.user, "cas_account"):
            return self.handle_no_permission()
        return super().dispatch(request, *args, **kwargs)


class LocalUserOnlySoftMixin(LocalUserOnlyMixin):
    redirect_url = None
    reject_message = ""

    def handle_no_permission(self):
        messages.warning(self.request, self.reject_message)
        return HttpResponseRedirect(str(self.redirect_url))
