{
  sources ? import ../npins,
  pkgs ? import sources.nixpkgs { },
}:

let
  check = (import sources.git-hooks).run {
    src = ./.;

    hooks = {
      # JS hooks
      # eslint.enable = true;

      # Python hooks
      ruff.enable = true;
      black.enable = true;
      isort.enable = true;

      # Nix Hooks
      statix.enable = true;
      deadnix.enable = true;
      rfc101 = {
        enable = true;

        name = "RFC-101 formatting";
        entry = "${pkgs.lib.getExe pkgs.nixfmt-rfc-style}";
        files = "\\.nix$";
      };

      # Misc Hooks
      commitizen.enable = true;
    };
  };
  python = pkgs.python3.override {
    packageOverrides = self: _: {
      authens = self.callPackage ./authens { };
      pythoncas = self.callPackage ./python-cas { };
      django-browser-reload = self.callPackage ./django-browser-reload { };
      django-solo = self.callPackage ./django-solo { };
      django-bulma-forms = self.callPackage ./django-bulma-forms { };
      django-sass-processor = self.callPackage ./django-sass-processor { };
      django-sass-processor-dart-sass = self.callPackage ./django-sass-processor-dart-sass { };
    };
  };
in
pkgs.mkShell {
  buildInputs = [
    pkgs.jq
    pkgs.dart-sass

    (python.withPackages (ps: [
      ps.django
      ps.gunicorn
      ps.authens
      ps.django-solo
      ps.django-browser-reload
      ps.django-bulma-forms
      ps.django-sass-processor
      ps.django-sass-processor-dart-sass
      ps.django-types

      #Debug
      ps.django-debug-toolbar
      ps.black
      ps.isort
    ]))

    pkgs.djlint
  ] ++ check.enabledPackages;
  shellHook = ''
    ${check.shellHook}
  '';

}
